@@ -7,12 +7,12 @@ import tornado.template
 from invoke import task
 from .db import revise, upgrade
 from .docker import docker
-from .utils import confirm_action, Colored
+from .utils import qname_to_class, confirm_action, Colored
 
 LOGGER = logging.getLogger(__name__)
 
 
-@task
+@task(help={"project": "name of project"})
 def create(ctx, project):
     """ creates a new project with a sqlite db """
     if os.path.isdir(project):
@@ -47,3 +47,12 @@ def run(_, package):
     """ run a liteblue project """
     app = import_module(package)
     app.main()
+
+
+@task(help={"config": "config.Config module path"})
+def worker(_, config):
+    """ run a liteblue worker """
+    from liteblue.worker import main  # pylint: disable=C0415
+
+    cfg_ = qname_to_class(config)
+    main(cfg_)
