@@ -4,6 +4,7 @@
 import os
 import logging
 import logging.config
+from importlib import import_module
 from contextlib import contextmanager
 
 LOGGER = logging.getLogger(__name__)
@@ -62,3 +63,11 @@ def confirm_action(action):
     while choice not in ["y", "n"]:
         choice = input(f"{action} [Y/N] ").lower()
     return choice == "y"
+
+
+def qname_to_class(qname):
+    """ returns a class from module_name:class_name """
+    if isinstance(qname, str):
+        _modules, _class = qname.split(":")
+        return getattr(import_module(_modules), _class)
+    return qname
